@@ -4,19 +4,19 @@
  *  Copyright (C) 2009 Alessandro Zummo <a.zummo@towertech.it>
  *
  *
- *   This library is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2 of
- *   the License, or (at your option) any later version.
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *   This program is distributed in the hope that it will be useful,
+ *   This library is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Library General Public License for more details.
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *   You should have received a copy of the GNU Library General Public
+ *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -100,8 +100,10 @@ static const struct kenwood_id_string kenwood_id_string_list[] = {
 	{ RIG_MODEL_THD7A,	"TH-D7" },
 	{ RIG_MODEL_THD7AG,	"TH-D7G" },
 	{ RIG_MODEL_TMD700,	"TM-D700" },
+	{ RIG_MODEL_TMD710,	"TM-D710" },
 	{ RIG_MODEL_THD72A,	"TH-D72" },
 	{ RIG_MODEL_TMV7,	"TM-V7" },
+	{ RIG_MODEL_TMV71,	"TM-V71" },
 	{ RIG_MODEL_THF6A,	"TH-F6" },
 	{ RIG_MODEL_THF7E,	"TH-F7" },
 	{ RIG_MODEL_THG71,	"TH-G71" },
@@ -133,8 +135,20 @@ const tone_t kenwood38_ctcss_list[] = {
 };
 
 
-/* Token definitions for .cfgparams in rig_caps 
- * 
+/*
+ * 42 CTCSS sub-audible tones
+ */
+const tone_t kenwood42_ctcss_list[] = {
+         670,  693,  719,  744,  770,  797,  825,  854,  885,  915,  948,
+	 974, 1000, 1035, 1072, 1109, 1148, 1188, 1230, 1273, 1318,
+	1365, 1413, 1462, 1514, 1567, 1622, 1679, 1738, 1799, 1862,
+        1928, 2035, 2065, 2107, 2181, 2257, 2291, 2336, 2418, 2503, 2541,
+	0,
+};
+
+
+/* Token definitions for .cfgparams in rig_caps
+ *
  * See enum rig_conf_e and struct confparams in rig.h
  */
 const struct confparams kenwood_cfg_params[] = {
@@ -1538,8 +1552,6 @@ int kenwood_get_func(RIG *rig, vfo_t vfo, setting_t func, int *status)
  *
  * Warning! This is untested stuff! May work at least on TS-870S
  * 	Please owners report to me <fillods@users.sourceforge.net>, thanks. --SF
-
- * TODO: TS-2000 uses CN/CT
  */
 int kenwood_set_ctcss_tone(RIG *rig, vfo_t vfo, tone_t tone)
 {
@@ -1579,8 +1591,8 @@ int kenwood_set_ctcss_tone_tn(RIG *rig, vfo_t vfo, tone_t tone)
 	char buf[6];
 	int i;
 
-	/* XXX 38 is a fixed constant */
-	for (i = 0; caps->ctcss_list[i] != 0 && i < 38; i++) {
+	/* XXX 40 is a fixed constant */
+	for (i = 0; caps->ctcss_list[i] != 0 && i < 40; i++) {
 		if (tone == caps->ctcss_list[i])
 			break;
 	}
@@ -1640,6 +1652,70 @@ int kenwood_get_ctcss_tone(RIG *rig, vfo_t vfo, tone_t *tone)
 	return RIG_OK;
 }
 
+int kenwood_set_ctcss_sql(RIG *rig, vfo_t vfo, tone_t tone)
+{
+	rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
+	if (!rig)
+		return -RIG_EINVAL;
+
+	const struct rig_caps *caps = rig->caps;
+	char buf[6];
+	int i;
+
+	for (i = 0; caps->ctcss_list[i] != 0 && i < 40; i++) {
+		if (tone == caps->ctcss_list[i])
+			break;
+	}
+
+	if (tone != caps->ctcss_list[i])
+		return -RIG_EINVAL;
+
+	sprintf(buf, "CN%02d", i + 1);
+
+	return kenwood_simple_cmd(rig, buf);
+}
+
+int kenwood_get_ctcss_sql(RIG *rig, vfo_t vfo, tone_t *tone)
+{
+	rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
+
+	if (!rig || !tone)
+		return -RIG_EINVAL;
+
+	const struct rig_caps *caps;
+	char tonebuf[6];
+	int i, retval;
+	unsigned int tone_idx;
+
+	caps = rig->caps;
+
+	retval = kenwood_safe_transaction(rig, "CT", tonebuf, 6, 5);
+	if (retval != RIG_OK)
+		return retval;
+
+	tone_idx = atoi(tonebuf+2);
+
+	if (tone_idx == 0) {
+		rig_debug(RIG_DEBUG_ERR, "%s: CTCSS is zero (%s)\n",
+					__func__, tonebuf);
+		return -RIG_EPROTO;
+	}
+
+	/* check this tone exists. That's better than nothing. */
+	for (i = 0; i<tone_idx; i++) {
+		if (caps->ctcss_list[i] == 0) {
+			rig_debug(RIG_DEBUG_ERR, "%s: CTCSS NG (%04d)\n",
+						__func__, tone_idx);
+			return -RIG_EPROTO;
+		}
+	}
+	*tone = caps->ctcss_list[tone_idx-1];
+
+	return RIG_OK;
+}
+
+
 /*
  * set the aerial/antenna to use
  */
@@ -2460,6 +2536,7 @@ DECLARE_INITRIG_BACKEND(kenwood)
 	rig_register(&thf7e_caps);
 	rig_register(&thg71_caps);
 	rig_register(&tmv7_caps);
+	rig_register(&tmd710_caps);
 
 	rig_register(&ts590_caps);
 	rig_register(&ts590_caps);
