@@ -8,20 +8,19 @@
  * via serial interface to an FT-990 using the "CAT" interface
  *
  *
+ *   This library is free software; you can redistribute it and/or
+ *   modify it under the terms of the GNU Lesser General Public
+ *   License as published by the Free Software Foundation; either
+ *   version 2.1 of the License, or (at your option) any later version.
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
+ *   This library is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *   Lesser General Public License for more details.
  *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
- *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ *   You should have received a copy of the GNU Lesser General Public
+ *   License along with this library; if not, write to the Free Software
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -138,7 +137,7 @@ const struct rig_caps ft990_caps = {
   .rig_model =          RIG_MODEL_FT990,
   .model_name =         "FT-990",
   .mfg_name =           "Yaesu",
-  .version =            "0.2",
+  .version =            "0.2.1",
   .copyright =          "LGPL",
   .status =             RIG_STATUS_ALPHA,
   .rig_type =           RIG_TYPE_TRANSCEIVER,
@@ -2223,15 +2222,11 @@ int ft990_get_mem(RIG *rig, vfo_t vfo, int *ch)
  */
 int ft990_set_channel (RIG *rig, const channel_t *chan)
 {
-  struct ft990_priv_data *priv;
-
   rig_debug(RIG_DEBUG_VERBOSE, "%s called\n", __func__);
 
   if (!rig)
     return -RIG_EINVAL;
 
-  priv = (struct ft990_priv_data *) rig->state.priv;
-
   return -RIG_ENIMPL;
 }
 
@@ -2322,7 +2317,7 @@ int ft990_get_channel (RIG *rig, channel_t *chan)
         chan->vfo = RIG_VFO_MEM;
   }
 
-  /* 
+  /*
    * Get data for selected VFO/MEM
    */
   err = ft990_get_update_data(rig, ci, chan->channel_num);
@@ -2334,14 +2329,14 @@ int ft990_get_channel (RIG *rig, channel_t *chan)
   if (p->bpf & FT990_EMPTY_MEM)
     return RIG_OK;
 
-  /* 
+  /*
    * Get RX frequency
    */
   chan->freq = ((((p->basefreq[0] << 8) + p->basefreq[1]) << 8) +
                    p->basefreq[2]) * 10;
 
   /*
-   * Get RX operating mode 
+   * Get RX operating mode
    */
   switch(p->mode) {
     case FT990_MODE_LSB:
@@ -2458,7 +2453,7 @@ int ft990_get_channel (RIG *rig, channel_t *chan)
     chan->tx_freq = ((((p->basefreq[0] << 8) + p->basefreq[1]) << 8) +
                      p->basefreq[2]) * 10;
     /*
-     * Get RX operating mode 
+     * Get RX operating mode
      */
     switch(p->mode) {
       case FT990_MODE_LSB:
